@@ -213,7 +213,10 @@ print.bcdc_query <- function(x, ...) {
 #' `TRUE` are kept. Accepts normal R expressions as well as any of the special
 #' [CQL geometry functions][cql_geom_predicates] such as `WITHIN()` or `INTERSECTS()`.
 #' If you know `CQL` and want to write a `CQL` query directly, write it enclosed
-#' in quotes, wrapped in the [CQL()] function. e.g., `CQL("ID = '42'")`
+#' in quotes, wrapped in the [CQL()] function. e.g., `CQL("ID = '42'")`.
+#'
+#' If your filter expression contains calls that need to be executed locally, wrap them
+#' in `local()` to force evaluation in R before the request is sent to the server.
 #'
 #' @describeIn filter filter.bcdc_promise
 #' @examples
@@ -229,11 +232,28 @@ print.bcdc_query <- function(x, ...) {
 #'     filter(FIRE_YEAR == 2000, FIRE_CAUSE == "Person", INTERSECTS(crd)) %>%
 #'     collect()
 #' )
-#'   }
+#'
+#' # Use local() to force parts of your call to be evaluated in R:
+#' try({
+#'   # Create a bounding box around two points and use that to filter
+#'   # the remote data set
+#'   library(sf)
+#'   two_points <- st_sfc(st_point(c(1164434, 368738)),
+#'                      st_point(c(1203023, 412959)),
+#'                      crs = 3005)
+#'
+#'   # Wrapping the call to `st_bbox()` in `local()` ensures that it
+#'   # is executed in R to make a bounding box that is then sent to
+#'   # the server for the filtering operation:
+#'   res <- bcdc_query_geodata("local-and-regional-greenspaces") %>%
+#'     filter(BBOX(local(st_bbox(two_points, crs = st_crs(two_points))))) %>%
+#'     collect()
+#' })
+#' }
 #' @export
 filter.bcdc_promise <- function(.data, ...) {
 
-  current_cql = cql_translate(...)
+  current_cql = cql_translate(..., .colnames = .data$cols_df$col_name %||% character(0))
   ## Change CQL query on the fly if geom is not GEOMETRY
   current_cql = specify_geom_name(.data$cols_df, current_cql)
 
